| Title: | Open Database Connectivity Resource Resolver |
|---|---|
| Description: | A database resource that is accessible through the Open Database Connectivity ('ODBC') API. This package uses the Resource model, with URL "resolver" and "client", to dynamically discover and make accessible tables stored in a 'MS SQL Server' database. For more details see Marcon (2021) <doi:10.1371/journal.pcbi.1008880>. |
| Authors: | Yannick Marcon [aut, cre] (ORCID: <https://orcid.org/0000-0003-0138-2023>), OBiBa group [cph] |
| Maintainer: | Yannick Marcon <[email protected]> |
| License: | LGPL (>= 2.1) |
| Version: | 1.0.0 |
| Built: | 2026-05-24 06:24:14 UTC |
| Source: | https://github.com/obiba/odbc.resourcer |
MS SQL DBI resource connector
MS SQL DBI resource connector
A R6 object of class MSSQLResourceConnector
Makes a ODBC DBI connection to a MS SQL server from a resource description.
resourcer::DBIResourceConnector -> odbc.resourcer::ODBCResourceConnector -> MSSQLResourceConnector
new()
Creates a new MSSQLResourceConnector instance.
MSSQLResourceConnector$new()
A MSSQLResourceConnector object.
isFor()
Check that the provided resource has a URL that locates a MS SQL object: the URL scheme must be "odbc+mssql".
MSSQLResourceConnector$isFor(resource)
resourceThe resource object to validate.
A logical.
getConnectionParameters()
Get the MS SQL ODBC driver connection string.
MSSQLResourceConnector$getConnectionParameters(resource)
resourceA valid resource object.
The MS SQL ODBC driver connection parameters list.
clone()
The objects of this class are cloneable with this method.
MSSQLResourceConnector$clone(deep = FALSE)
deepWhether to make a deep clone.
## Not run: # Create a resource res <- resourcer::newResource( url = "odbc+mssql://localhost:1433/EpidemiologyDB/PatientData", identity = "sa", secret = "YourStrong@Password123") # Create a resource client client <- resourcer::newResourceClient(res) # Coerce resource to a data frame df <- client$asDataFrame() # Disconnect the client client$close() ## End(Not run)## Not run: # Create a resource res <- resourcer::newResource( url = "odbc+mssql://localhost:1433/EpidemiologyDB/PatientData", identity = "sa", secret = "YourStrong@Password123") # Create a resource client client <- resourcer::newResourceClient(res) # Coerce resource to a data frame df <- client$asDataFrame() # Disconnect the client client$close() ## End(Not run)
ODBC DBI resource connector
ODBC DBI resource connector
A R6 object of class ODBCResourceConnector
Makes a ODBC DBI connection from a resource description.
resourcer::DBIResourceConnector -> ODBCResourceConnector
new()
Creates a new ODBCResourceConnector instance.
ODBCResourceConnector$new()
A ODBCResourceConnector object.
isFor()
Check that the provided resource has a URL that locates a ODBC object: the URL scheme must start with "odbc".
ODBCResourceConnector$isFor(resource)
resourceThe resource object to validate.
A logical.
createDBIConnection()
Creates a DBI connection object from a resource.
ODBCResourceConnector$createDBIConnection(resource)
resourceA valid resource object.
A DBI connection object.
getConnectionParameters()
Get the specific ODBC driver connection string.
ODBCResourceConnector$getConnectionParameters(resource)
resourceA valid resource object.
The ODBC driver connection parameters list.
clone()
The objects of this class are cloneable with this method.
ODBCResourceConnector$clone(deep = FALSE)
deepWhether to make a deep clone.